/************************************************/
/* PURPOSE:       Takes as input a list of SAS data library members (usually dataset names),
/*                and replaces the macro call with the names of any that already exist.
/* 
/* INPUT:         DATALST: Space-delimited list of SAS data library members, usually dataset names     	  
/* OUTPUT:  	  NA
/* MACROS USED:   NA
/*
/* EXAMPLES:      Example 1: Do something if any of the datasets exist
/*                  %let exstsets=%alrdexst(tmp1 tmp2 tmp3);
/*                  %if  %length(&exstsets)>0 %then %do;
/*                  %put ...maybe some warning....;
/*                  ... maybe exit the calling macro or program...;
/*                  %end;
/*                Example 2:  Do something if all of the datasets exist
/*                  %if %str(tmp1 tmp2 tmp3)=%alrdexst(tmp1 tmp2 tmp3) %then %do;
/*                    ... do something ...;
/*                  %end; 
/*    
/* NOTES:         This macro does not print warnings, errors, or exit the program.
/*                It assumes the calling program will do whatever is appropriate.      
/*
/************************************************/

%macro alrdexst(DATALST);
   %local i DSN ALREADYX;

   %do i=1 %to %sysfunc(countw(&DATALST,%str( )));
      %let dsn=%scan(&DATALST,&i,%str( ));
      %if %sysfunc(exist(&DSN))=1 %then
         %let alreadyx=%cmpres(&ALREADYX &DSN);
   %end;
   %if %length(&ALREADYX) %then %do;
     &ALREADYX
   %end;

%mend;
