/************************************************/
/* PURPOSE:       Check if all required parameters are supplied. 
/* SOURCE PRGM:   NA
/*
/* INPUT:         PARAMLIST = list of macro parameters separated by blanks   
/* OUTPUT:  	  Return error message and end SAS session if any required parameters are missing
/* MACROS USED:   NA
/*
/* EXAMPLES:      %paramreq(indata col row)
/* NOTES:           
/* MODIFICATIONS:	  
/************************************************/
%macro paramreq(PARAMLST);
   %local i PARAM MISSING ;

   /* create list of macro parameters that have not been specified */
   %do i=1 %to %sysfunc(countw(&PARAMLST));
      %let PARAM=%scan(&PARAMLST,&i);
      %if %length(&&&PARAM)=0 %then %do;
         %let missing=%cmpres(&MISSING &PARAM);
      %end;
   %end;

   /* if any parameters left blank return error message */ 
   %if %length(&MISSING) %then %do;
       %put %upcase(error): Required parameter(s) &MISSING unspecified; 
       endsas;
   %end;
   
%mend;
